/*****************************************************************************
 * Copyright (C) 2014-2018
 *
 * Michiel Broek <mbroek at mbse dot eu>
 *
 * This file is part of BrewCloud
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * BrewCloud is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ThermFerm; see the file COPYING.  If not, write to the Free
 * Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *****************************************************************************/


function createDelElements() {
	$('#eventWindow').jqxWindow({
		theme: theme,
		position: { x: 490, y: 210 },
		width: 300,
		height: 175,
		resizable: false,
		isModal: true,
		modalOpacity: 0.4,
		okButton: $('#delOk'),
		cancelButton: $('#delCancel'),
		initContent: function () {
			$('#delOk').jqxButton({ width: '65px', theme: theme });
			$('#delCancel').jqxButton({ width: '65px', theme: theme });
			$('#delCancel').focus();
		}
	});
	$('#eventWindow').jqxWindow('hide');
}


$(document).ready(function () {
	var url = "includes/db_inventory_water_profiles.php";
	// prepare the data
	var source = {
		datatype: "json",
		cache: false,
		datafields: [
			{ name: 'record', type: 'number' },
			{ name: 'name', type: 'string' },
			{ name: 'calcium', type: 'float' },
			{ name: 'bicarbonate', type: 'float' },
			{ name: 'sulfate', type: 'float' },
			{ name: 'chloride', type: 'float' },
			{ name: 'sodium', type: 'float' },
			{ name: 'magnesium', type: 'float' },
			{ name: 'ph', type: 'float' },
			{ name: 'notes', type: 'string' },
			{ name: 'total_alkalinity', type: 'float' }
		],
		id: 'record',
		url: url,
		deleterow: function (rowid, commit) {
			// synchronize with the server - send delete command
			var data = "delete=true&" + $.param({ record: rowid });
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				success: function (data, status, xhr) {
					// delete command is executed.
					commit(true);
				},
				error: function (jqXHR, textStatus, errorThrown) {
					commit(false);
				}
			});
		},
		addrow: function (rowid, rowdata, position, commit) {
			var data = "insert=true&" + $.param(rowdata);
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				success: function (data, status, xhr) {
					commit(true);
				},
				error: function(jqXHR, textStatus, errorThrown) {
                                        commit(false);
                                }
                        });
                },
		updaterow: function (rowid, rowdata, commit) {
			var data = "update=true&" + $.param(rowdata);
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				success: function (data, status, xhr) {
					// update command is executed.
					commit(true);
				},
				error: function(jqXHR, textStatus, errorThrown) {
					commit(false);
				}
			});
		}
	};
	// initialize the input fields.
	$("#name").jqxInput({ theme: theme, width: 250, height: 23 });
	$("#calcium").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, decimalDigits: 1, spinButtons: true });
	$("#bicarbonate").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, decimalDigits: 1, spinButtons: true });
	$("#sulfate").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, decimalDigits: 1, spinButtons: true });
	$("#chloride").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, decimalDigits: 1, spinButtons: true });
	$("#sodium").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, decimalDigits: 1, spinButtons: true });
	$("#magnesium").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, decimalDigits: 1, spinButtons: true });
	$("#ph").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, decimalDigits: 1, spinButtons: true });

	$("#notes").jqxInput({ theme: theme, width: 640, height: 100 });
	$("#total_alkalinity").jqxNumberInput({ inputMode: 'simple', spinMode: 'simple', theme: theme, width: 70, height: 23, min: 0, decimalDigits: 1, spinButtons: true });
	var dataAdapter = new $.jqx.dataAdapter(source);
	var editrow = -1;
	// initialize jqxGrid
	$("#jqxgrid").jqxGrid({
		width: 1280,
		height: 630,
		source: dataAdapter,
		theme: theme,
		showstatusbar: true,
		localization: getLocalization(),
		renderstatusbar: function (statusbar) {
			var container = $("<div style='overflow: hidden; position: relative; margin: 5px;'></div>");
			var addButton = $("<div style='float: right; margin-right: 15px;'><img style='position: relative; margin-top: 2px;' src='images/add.png'/><span style='margin-left: 4px; position: relative; top: -3px;'>Nieuw</span></div>");
			container.append(addButton);
			statusbar.append(container);
			addButton.jqxButton({ theme: theme, width: 120, height: 20 });
			// add new row.
			addButton.click(function (event) {
				editrow = -1;
				$("#popupWindow").jqxWindow({ position: { x: 230, y: 30 } });
				$("#name").val('');
				$("#calcium").val('');
				$("#bicarbonate").val('');
				$("#sulfate").val('');
				$("#chloride").val('');
				$("#sodium").val('');
				$("#magnesium").val('');
				$("#ph").val('');
				$("#notes").val('');
				$("#total_alkalinity").val('');
				$("#popupWindow").jqxWindow('open');
			});
		},
		filterable: true,
		filtermode: 'excel',
		columns: [
			{ text: 'Water Profiel', datafield: 'name', width: 250 },
			{ text: 'Opmerkingen', datafield: 'notes', width: 475 },
			{ text: 'Natrium', datafield: 'sodium', width: 80, align: 'right', cellsalign: 'right', cellsformat: 'f1' },
			{ text: 'Chloride', datafield: 'chloride', width: 80, align: 'right', cellsalign: 'right', cellsformat: 'f1' },
			{ text: 'Sulfaat', datafield: 'sulfate', width: 80, align: 'right', cellsalign: 'right', cellsformat: 'f1' },
			{ text: 'Zuurgraad', datafield: 'ph', width: 80, align: 'right', cellsalign: 'right', cellsformat: 'f1' },
			{ text: 'Alkaliteit', datafield: 'total_alkalinity', width: 80, align: 'right', cellsalign: 'right', cellsformat: 'f1' },
			{ text: 'Wijzig', datafield: 'Edit', columntype: 'button', cellsrenderer: function () {
				return "Wijzig";
				}, buttonclick: function (row) {
					// open the popup window when the user clicks a button.
					editrow = row;
					$("#popupWindow").jqxWindow({ position: { x: 230, y: 30 } });
					// get the clicked row's data and initialize the input fields.
					var dataRecord = $("#jqxgrid").jqxGrid('getrowdata', editrow);
					$("#name").val(dataRecord.name);
					$("#calcium").val(dataRecord.calcium);
					$("#bicarbonate").val(dataRecord.bicarbonate);
					$("#sulfate").val(dataRecord.sulfate);
					$("#chloride").val(dataRecord.chloride);
					$("#sodium").val(dataRecord.sodium);
					$("#magnesium").val(dataRecord.magnesium);
					$("#ph").val(dataRecord.ph);
					$("#notes").val(dataRecord.notes);
					$("#total_alkalinity").val(dataRecord.total_alkalinity);
					// show the popup window.
					$("#popupWindow").jqxWindow('open');
				}
			}
		]
	});
	// initialize the popup window and buttons.
	$("#popupWindow").jqxWindow({
		width: 860, resizable: false, theme: theme, isModal: true, autoOpen: false, cancelButton: $("#Cancel"), modalOpacity: 0.40
	});
	$("#popupWindow").on('open', function () {
		$("#name").jqxInput('selectAll');
	});
	$("#Delete").jqxButton({ theme: theme });
	$("#Delete").click(function () {
		if (editrow >= 0) {
			// Open a popup to confirm this action.
			$('#eventWindow').jqxWindow('open');
			$("#delOk").click(function () {
				var rowID = $('#jqxgrid').jqxGrid('getrowid', editrow);
				$("#jqxgrid").jqxGrid('deleterow', rowID);
			});
		}
		$("#popupWindow").jqxWindow('hide');
	});
	$("#Cancel").jqxButton({ theme: theme });
	$("#Save").jqxButton({ theme: theme });
	// update the edited row when the user clicks the 'Save' button.
	$("#Save").click(function () {
		if (editrow >= 0) {
			var rowID = $('#jqxgrid').jqxGrid('getrowid', editrow);
			var row = {
				record: rowID,
				name: $("#name").val(),
				calcium: parseFloat($("#calcium").jqxNumberInput('decimal')),
				bicarbonate: parseFloat($("#bicarbonate").jqxNumberInput('decimal')),
				sulfate: parseFloat($("#sulfate").jqxNumberInput('decimal')),
				chloride: parseFloat($("#chloride").jqxNumberInput('decimal')),
				sodium: parseFloat($("#sodium").jqxNumberInput('decimal')),
				magnesium: parseFloat($("#magnesium").jqxNumberInput('decimal')),
				ph: parseFloat($("#ph").jqxNumberInput('decimal')),
				notes: $("#notes").val(),
				total_alkalinity: parseFloat($("#total_alkalinity").jqxNumberInput('decimal'))
			};
			$('#jqxgrid').jqxGrid('updaterow', rowID, row);
			$("#popupWindow").jqxWindow('hide');
		} else {
			// Insert a record
			var newrow = {
				record: -1,
				name: $("#name").val(),
				calcium: parseFloat($("#calcium").jqxNumberInput('decimal')),
				bicarbonate: parseFloat($("#bicarbonate").jqxNumberInput('decimal')),
				sulfate: parseFloat($("#sulfate").jqxNumberInput('decimal')),
				chloride: parseFloat($("#chloride").jqxNumberInput('decimal')),
				sodium: parseFloat($("#sodium").jqxNumberInput('decimal')),
				magnesium: parseFloat($("#magnesium").jqxNumberInput('decimal')),
				ph: parseFloat($("#ph").jqxNumberInput('decimal')),
				notes: $("#notes").val(),
				total_alkalinity: parseFloat($("#total_alkalinity").jqxNumberInput('decimal'))
			};
			$('#jqxgrid').jqxGrid('addrow', null, newrow);
			$("#popupWindow").jqxWindow('hide');
		}
	});
	createDelElements();
});

